netapp_ontap.models.ddns API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.ddns`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DdnsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Ddns object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `enabled: bool GET POST PATCH`

    Enable or disable Dynamic DNS (DDNS) updates for the specified SVM.

  `fqdn: str GET POST PATCH`

    Fully Qualified Domain Name (FQDN) to be used for dynamic DNS updates.

    Example: example.com

  `skip_fqdn_validation: bool PATCH`

    Enable or disable FQDN validation.

  `time_to_live: str GET POST PATCH`

    Time to live value for the dynamic DNS updates, in an ISO-8601 duration formatted string. Maximum Time To Live is 720 hours(P30D in ISO-8601 format) and the default is 24 hours(P1D in ISO-8601 format).

    Example: P2D

  `use_secure: bool GET POST PATCH`

    Enable or disable secure dynamic DNS updates for the specified SVM.